// src/GistViewer.jsx
import React, { useState, useEffect } from 'react';
import axios from 'axios';

const GistViewer = ({ gistId }) => {
  const [gistContent, setGistContent] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    const fetchGist = async () => {
      try {
        const response = await axios.get(`https://api.github.com/gists/${gistId}`);
        setGistContent(response.data);
      } catch (err) {
        setError(err);
      } finally {
        setLoading(false);
      }
    };

    fetchGist();
  }, [gistId]);

  if (loading) return <p>Loading...</p>;
  if (error) return <p>Error loading gist: {error.message}</p>;

  return (
    <div>
      <h2>{gistContent.description || 'Gist'}</h2>
      <pre>
        <code>{JSON.stringify(gistContent, null, 2)}</code>
      </pre>
    </div>
  );
};

export default GistViewer;
